/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *   * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */

package org.wso2.registry.ui.actions;

import com.opensymphony.xwork2.ActionSupport;
import com.opensymphony.xwork2.ActionContext;

import java.util.List;
import java.util.ArrayList;

import org.wso2.registry.*;
import org.wso2.registry.jdbc.JDBCRegistry;
import org.wso2.registry.secure.SecureRegistry;
import org.wso2.registry.secure.AuthorizationFailedException;
import org.wso2.registry.ui.WebAppConstants;
import org.apache.struts2.StrutsStatics;

import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;

public class CollectionViewAction extends AbstractRegistryAction {

    private String path;

    private List resourceDataList = new ArrayList();

    public String execute() throws Exception {

        // get the resource for the path
        // get all its children and fill ResourceOverview objects
        // add ResourceOverview object to the resourceDataList list

        Registry registry = getRegistry();

        // if path is not set, we assume that root "/" is requested
        if (path == null || path.length() == 0) {
            path = RegistryConstants.ROOT_PATH;
        }

        Artifact artifact = null;
        try {
            artifact = registry.get(path);
        } catch (AuthorizationFailedException e) {
            return ActionSupport.SUCCESS;
        }
        if (artifact == null) {
            return ActionSupport.ERROR;
        }

        String[] childPaths = (String[]) artifact.getContent();

        for (int i = 0; i < childPaths.length; i++) {

            Artifact child = null;
            try {
                child = registry.get(childPaths[i]);
            } catch (AuthorizationFailedException e) {
                continue;
            }

            ResourceData resourceData = new ResourceData();
            resourceData.setPath(child.getPath());

            if (child.getPath() != null) {
                String[] parts = child.getPath().split(RegistryConstants.PATH_SEPARATOR);
                resourceData.setName(parts[parts.length - 1]);
            }

            resourceData.setAuthorUserName(child.getAuthorUserName());
            resourceData.setDescription(child.getDescription());
            resourceData.setRating(registry.getAverageRating(child.getPath()));
            resourceDataList.add(resourceData);
        }

        return ActionSupport.SUCCESS;
    }

    public String getPath() {
        return path;
    }

    public void setPath(String path) {
        this.path = path;
    }   

    public List getResourceDataList() {
        return resourceDataList;
    }

    public void setResourceDataList(List resourceDataList) {
        this.resourceDataList = resourceDataList;
    }
}
